@@ -16,7 +16,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: memcache.c,v 1.23 2004/11/05 07:16:13 tony2001 Exp $ */
+/* $Id: memcache.c,v 1.25 2005/08/05 11:38:37 tony2001 Exp $ */
 
 /* TODO
  * - we should probably do a cleanup if some call failed, 
@@ -190,7 +190,7 @@ PHP_MINIT_FUNCTION(memcache)
 #endif
 	
 	REGISTER_LONG_CONSTANT("MEMCACHE_COMPRESSED",MMC_COMPRESSED, CONST_CS | CONST_PERSISTENT);
-	
+
 	return SUCCESS;
 }
 /* }}} */
@@ -231,7 +231,7 @@ PHP_MINFO_FUNCTION(memcache)
 	php_info_print_table_start();
 	php_info_print_table_header(2, "memcache support", "enabled");
 	php_info_print_table_row(2, "Active persistent connections", buf);
-	php_info_print_table_row(2, "Revision", "$Revision: 1.23 $");
+	php_info_print_table_row(2, "Revision", "$Revision: 1.25 $");
 	php_info_print_table_end();
 }
 /* }}} */
@@ -725,13 +725,13 @@ static int mmc_exec_retrieval_cmd(mmc_t *mmc, char *command, int command_len, ch
 		    if (size == 0) break;
 		    offset += size, data_to_be_read -= size;
 		}
-
+		
 		if (data_to_be_read > 0) {
 			php_error_docref(NULL TSRMLS_CC, E_NOTICE, "incomplete data block (expected %d, got %d)", (*data_len + 2), offset);
 			efree(*data);
 			return -1;
 		}
-
+		
 		(*data) [*data_len] = '\0';
 		MMC_DEBUG(("mmc_exec_retrieval_cmd: data '%s'", *data));
 	}
@@ -845,7 +845,7 @@ static int mmc_exec_retrieval_cmd_multi(mmc_t *mmc, zval *keys, zval **result TS
 			MMC_DEBUG(("mmc_exec_retrieval_cmd: data '%s'", data));
 		}
 
-		if (!data || !data_len) {
+		if (!data) {
 			add_assoc_bool(*result, tmp_name, 0);
 			efree(tmp_name);
 			continue;
@@ -1415,8 +1415,6 @@ connect_done:
 		add_property_resource(return_value, "connection",mmc->id);
 	}
 	else {
-		zval_dtor(mmc_object);
-		object_init_ex(mmc_object, memcache_class_entry_ptr);
 		add_property_resource(mmc_object, "connection",mmc->id);
 		RETURN_TRUE;
 	}	
@@ -1526,7 +1524,7 @@ PHP_FUNCTION(memcache_get)
 
 		if (mmc_exec_retrieval_cmd(mmc, "get", sizeof("get") - 1, Z_STRVAL_P(key), Z_STRLEN_P(key), &flags, &data, &data_len TSRMLS_CC) > 0) {
 
-			if (!data || !data_len) {
+			if (!data) {
 				RETURN_EMPTY_STRING();
 			}
 			
